%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%funksjon som beregner induktans- og kapasitansmatrisa 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Inngangsparametre:
%%%%%%%%%%%%%%%%%%%
%phi1-vridning av kabel 1
%phi2-vridning av kabel 2
%antLedere-antall ledere i systemet
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function[L,C]=beregnInduktansKapasitans(phi1,phi2,antLedere);

%Parameterne som brukes i beregningen
%*********************************************************************
%f[kHz]-frekvens
%omega[rad/s]-vinkelfrekvens
%l[km]-kabellengde
%my[H/km]-permeabiliteten i vakuum
%epsiolonvak[F/km]-permittiviteten i vakuum
%epsilon_rel-relativ permittivitet = polyethylen
%Cd-driftskapsitans per lengdeenhet
%L-per-lengdeenhet-induktansmatrise
%C-per-lengdeenhet-kapasitansmatrise
%*********************************************************************

%faste parametre
my = 4*pi*10^(-7)*10^3; %permeabiliteten i vakuum, H/km
epsilon_vak = 8.8541878176*10^(-12)*10^3; %permittiviteten i vakuum, F/km
epsilon_rel = 2.25; %permittiviteten til polyethylen
epsilon = epsilon_vak*epsilon_rel; %permittiviteten, F/km

%kabelparametre
%%%%%%%%%%%%%%%%%%%%%%%
r_k=0.5; %lederradius kobber
r_l=1; %lednigsradius isolasjon (og kobber)
r=(2*r_l)/sqrt(2); %avstand fra midtpunkt av skjerm til midtpunkt av leder
r_s=r+r_l; %radius skjerm 
r_sp=r_s^2/r; %radius speilladninger
r_a=1; %avstanden mellom skjermene til hver av firelederne
d=2*r_s+r_a; %avstanden mellom midtpunkt av hver leder

%Beregning av selvinduktans
%%%%%%%%%%%%%%%%%%%%%%%%%%%
L11=(my/(2*pi))*(log((r_s^2-r^2)/(r_k*r_s)));
L22=L11;
L33=L11;
L44=L11;
L55=L11;
L66=L11;
L77=L11;
L88=L11;

%Beregning av induktanser innen hver kabel (fireleder)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%theta=90 grader
L12=(my/(2*pi))*(log(1/(r*r_s)*sqrt((r^4+r_s^4)/2)));
L21=L12;
L14=L12;
L41=L12;
L23=L12;
L32=L12;
L34=L12;
L43=L12;
L56=L12;
L65=L12;
L58=L12;
L85=L12;
L67=L12;
L76=L12;
L78=L12;
L87=L12;

bok90=(my/(2*pi))*log((r/r_s)*sqrt((r^4+r_s^4-2*r^2*r_s^2*cosd(90))/(r^4+r^4-2*r^4*cosd(90))));

%theta=180 grader
L13=(my/(2*pi))*(log((r_s^2+r^2)/(2*r*r_s)));
L31=L13;
L24=L13;
L42=L13;
L57=L13;
L75=L13;
L68=L13;
L86=L13;

bok180=(my/(2*pi))*log((r/r_s)*sqrt((r^4+r_s^4-2*r^2*r_s^2*cosd(180))/(r^4+r^4-2*r^4*cosd(180))));

%Koordinater til midtpunkt av ledere, origo i midtpunkt
%kabel 1
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
phi1;

x(1)=-r*sind(phi1);
y(1)=sqrt(r^2-x(1)^2);

x(2)=y(1);
y(2)=-x(1);

x(3)=-x(1);
y(3)=-y(1);

x(4)=-x(2);
y(4)=-y(2);

xk=r*sind(phi2);
yk=sqrt(r^2-xk^2);

x(5)=d-xk;
y(5)=yk;

x(6)=d+yk;
y(6)=xk;

x(7)=d+xk;
y(7)=-yk;

x(8)=d-yk;
y(8)=-xk;

x;
y;

%Koordinater til skjermer i kabel 1 og 2 ved respektiv leder
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
xk=r_s*sind(phi1);
yk=sqrt(r_s^2-xk^2);

skjerm_x(1)=-xk;
skjerm_y(1)=yk;

skjerm_x(2)=yk;
skjerm_y(2)=xk;

skjerm_x(3)=xk;
skjerm_y(3)=-yk;

skjerm_x(4)=-yk;
skjerm_y(4)=-xk;

xk=r_s*sind(phi2);
yk=sqrt(r_s^2-xk^2);

skjerm_x(5)=d-xk;
skjerm_y(5)=yk;

skjerm_x(6)=d+yk;
skjerm_y(6)=xk;

skjerm_x(7)=d+xk;
skjerm_y(7)=-yk;

skjerm_x(8)=d-yk;
skjerm_y(8)=-xk;

%Koordinater til midtpunkt av speilladninger
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
xk=r_sp*sind(phi1);
yk=sqrt(r_sp^2-xk^2);

speil_x(1)=-xk;
speil_y(1)=yk;

speil_x(2)=yk;
speil_y(2)=xk;

speil_x(3)=xk;
speil_y(3)=-yk;

speil_x(4)=-yk;
speil_y(4)=-xk;

xk=r_sp*sind(phi2);
yk=sqrt(r_sp^2-xk^2);

speil_x(5)=d-xk;
speil_y(5)=yk;

speil_x(6)=d+yk;
speil_y(6)=xk;

speil_x(7)=d+xk;
speil_y(7)=-yk;

speil_x(8)=d-yk;
speil_y(8)=-xk;


%Avstander mellom ledere
%%%%%%%%%%%%%%%%%%%%%%%%
for i=1:8 
    for j=1:8
        xdiff=abs(x(i)-x(j));
        ydiff=abs(y(i)-y(j));    
        a(i,j)=sqrt(xdiff^2+ydiff^2);        
    end
end

%Avstander mellom leder 1 til 8 og skjerm 1 til 8
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
for i=1:8 
    for j=1:8
        xdiff=abs(x(i)-skjerm_x(j));
        ydiff=abs(y(i)-skjerm_y(j));    
        a_leder_skjerm(i,j)=sqrt(xdiff^2+ydiff^2);        
    end
end

%Avstander mellom speilladninger og ledere
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
for i=1:8 
    for j=1:8        
        xdiff=abs(speil_x(i)-x(j));
        ydiff=abs(speil_y(i)-y(j));    
        a_speil_leder(i,j)=sqrt(xdiff^2+ydiff^2);
    end
end

%Avstander mellom speilladninger og skjermer 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
for i=1:8 
    for j=1:8        
        xdiff=abs(speil_x(i)-skjerm_x(j));
        ydiff=abs(speil_y(i)-skjerm_y(j));    
        a_speil_skjerm(i,j)=sqrt(xdiff^2+ydiff^2);
    end
end

%Beregning av induktanser
%%%%%%%%%%%%%%%%%%%%%%%%%
for i=1:8
    for j=1:8
        if(i==j)
            L(i,j)=(my/(2*pi))*(log((a_leder_skjerm(i,j)/r_k)*(a_speil_leder(i,j)/a_speil_skjerm(i,j))));            
        else
            L(i,j)=(my/(2*pi))*(log((a_leder_skjerm(i,j)/(a(i,j)))*((a_speil_leder(i,j))/(a_speil_skjerm(i,j)))));
        end
    end
end

L;

% % PLOTTING
% %%%%%%%%
% figure(1)
% plot(x,y,'r*')
% axis([-50 50 -50 50])
% hold on 
% l=zeros(1,100);
% m=-49:50;
% plot(l,m)
% plot(m,l)
% l=[d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d];
% plot(l,m)
% plot(skjerm_x,skjerm_y,'g*')
% plot(speil_x,speil_y,'m*')
% hold off

L4=L(1:4,1:4);
C4=inv(L4)*my*epsilon;
C=[C4 zeros(4,4);zeros(4,4) C4];

%beregner driftskapasitans
C1=abs(C(1,2));
C2=abs(C(1,3));
C0=C(1,1)-2*C1-C2;

Cd=(C2+C1+C0/2);
%Cd=45*10^(-9);

if(antLedere==2)
    c=2/3*Cd;
    C=[2*c -c;-c 2*c];
    L=my*epsilon*inv(C);
end
if(antLedere==4)
    L=L4;
    C=C4;
end


