%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%funksjon som beregner resistansmatrisa
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Inngangsparametre:
%%%%%%%%%%%%%%%%%%%
%dempning_dB-kabelens dempningskonstant
%antLedere-antall ledere i systemet
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function[R]=beregnResistans(dempning_dB, antLedere);

%Parameterne som brukes i beregningen
%*********************************************************************
%f[kHz]-frekvens
%omega[rad/s]-vinkelfrekvens
%dempning_dB[dB/km]-kabelens dempningskonstant i dB/km
%alfa[Np/km]-kabelens dempningskonstant i Np/km
%my[H/km]-permeabiliteten i vakuum
%epsiolonvak[F/km]-permittiviteten i vakuum
%epsilon_rel-relativ permittivitet = polyethylen
%antLedere-antall leder i systemet
%*********************************************************************

%faste parametere
%%%%%%%%%%%%%%%%%
my = 4*pi*10^(-7)*10^3; 
epsilon_vak = 8.8541878176*10^(-12)*10^3; 
epsilon_rel = 2.25; 
epsilon = epsilon_vak*epsilon_rel; 

alfa = dempning_dB*(1/(20*log10(exp(1))));

[L,C]=beregnInduktansKapasitans(0,0,8);

C1=abs(C(1,2));
C2=abs(C(1,3));
C0=C(1,1)-2*C1-C2;

ct=C2+C1+C0/2;
%ct=45*10^(-9);

lt=my*epsilon*inv(ct);
rt=2*alfa*sqrt(lt/ct);
r=rt/2;


if(antLedere==2)
    R=r*eye(2);
else if(antLedere==4)
        R=r*eye(4);
    else if(antLedere==8)
            R=r*eye(8);
        end
    end
end

