clc
close all
clear all

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Beregning av enkel transmisjonslinje for to ledere sammenlignet med for
%fire ledere koblet sammen
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Parameterne som brukes i beregningen
%*********************************************************************
%f[kHz]-frekvens
%omega[rad/s]-vinkelfrekvens
%l[km]-lengden av detektorslyfe som det ses p utgangsspenningen til 
%l2[km]-lengden av fellesstrekning
%l3[km]-lengden av den andre detektorslyfa 
%dempning_dB[dB/km]-kabelens dempningskonstant i dB/km
%alfa[Np/km]-kabelens dempningskonstant i Np/km
%my[H/km]-permeabiliteten i vakuum
%epsiolonvak[F/km]-permittiviteten i vakuum
%epsilon_rel-relativ permittivitet = polyethylen
%lt-induktans per lengdeenhet
%ct-kapsitans per lengdeenhet
%rt-resistans per lengdeenhet
%beta[rad/km]-fasekonstant
%Z0-karakteristisk impedans
%gamma-propagsjonskonstant
%L-per-lengdeenhet-induktansmatrise
%C-per-lengdeenhet-kapasitansmatrise
%R-per-lengdeenhet-resistansmatrise
%Z0-matrise for generalisert karakteristisk impedans
%GAMMA-matrise for generalisert propagsjonskonstant
%*********************************************************************

%faste parametre
%%%%%%%%%%%%%%%%
f=132*10^3;
omega = 2*pi*f;
dempning_dB=5.49;
alfa = dempning_dB*(1/(20*log10(exp(1))));

my = 4*pi*10^(-7)*10^3; 
epsilon_vak = 8.8541878176*10^(-12)*10^3; 
epsilon_rel = 2.25; 
epsilon = epsilon_vak*epsilon_rel; 

%%%%%%%%%%%%%%%%%%%%%
%system med to ledere
%%%%%%%%%%%%%%%%%%%%%

[L,C]=beregnInduktansKapasitans(0,0,2);
R=beregnResistans(dempning_dB,2);
[GAMMA2,Z02]=beregnGammaZ0(R,L,C);

%%%%%%%%%%%%%%%%%%%%%%%
%system med fire ledere
%%%%%%%%%%%%%%%%%%%%%%%

[L,C]=beregnInduktansKapasitans(0,0,2);
L=[L zeros(2,2);zeros(2,2) L];
C=my*epsilon*inv(L);
R=beregnResistans(dempning_dB,4);
[GAMMA4,Z04]=beregnGammaZ0(R,L,C);

%initialiserer
b=1;
c=1;
Htr2=zeros(1,(200));
Htr4=zeros(1,(200));
avvik=0;
maxavvikHtr=0;

%Beregner A-matriser og transferfunksjoner
for x=0.001:0.01:2

%A-matrise for to ledere 
A=[funm((x*GAMMA2), @cosh) (funm((x*GAMMA2), @sinh))*Z02 ; (funm((x*(GAMMA2.')), @sinh))*inv(Z02) funm((x*(GAMMA2.')), @cosh)];
A2=A;

A11=A(1:2,1:2);
A12=A(1:2,3:4);
A21=A(3:4,1:2);
A22=A(3:4,3:4);

M=inv(A21);
H=M(1)-M(2)-M(3)+M(4);%Htr=U21-U22

Htr2(c)=20*log10(abs(H));
c=c+1;


%A-matrise for fire ledere koblet sammen
A=[funm((x/2*GAMMA4), @cosh) (funm((x/2*GAMMA4), @sinh))*Z04 ; (funm((x/2*(GAMMA4.')), @sinh))*inv(Z04) funm((x/2*(GAMMA4.')), @cosh)];

A11=A(1:2,1:2);
A12=A(1:2,3:4);
A13=A(1:2,5:6);
A14=A(1:2,7:8);
A21=A(3:4,1:2);
A22=A(3:4,3:4);
A23=A(3:4,5:6);
A24=A(3:4,7:8);
A31=A(5:6,1:2); 
A32=A(5:6,3:4);
A33=A(5:6,5:6);
A34=A(5:6,7:8);
A41=A(7:8,1:2);
A42=A(7:8,3:4);
A43=A(7:8,5:6);
A44=A(7:8,7:8);

C=[A11+A12 (A13-A14); A31+A32 (A33-A34)];
D=[A21+A22 (A23-A24); (-A41-A42) (-A43+A44)];

M=C*inv(D);
M4=M;

M3=M(3:4,1:2);
MI=inv(M3);

H=MI(1)-MI(3)-MI(2)+MI(4);%Htr=U21-U22

Htr4(b)=20*log10(abs(H));


%beregner max avvik for matriseelementer i matrisene A2 og M4
for i=1:1:16
    if (abs(A2(i)-M4(i)))>avvik
    avvik=abs(A2(i)-M4(i));
    end
end

b=b+1;    
end

%beregning av maksimsalt avvik mellom Htr2 og Htr4
avvik=max(abs(Htr2-Htr4));

hold on
x=[0.001:0.01:2];
plot(x,Htr2);
x=[0.001:0.01:2];
plot(x,Htr4,'red:');

title('Overfringsfunksjon Htr ')
%tekst p akser for matlab
xlabel('x(km)');
ylabel('|Ztr|(dB)');
legend('To ledere','Fire ledere koblet sammen, 8x8 til 4x4');

