clear all
close all
clc
%*********************************************************************
%Enkel transmisjonslinje med og uten primre paramtre
%*********************************************************************

%Parameterne som brukes i beregningen
%*********************************************************************
%f[kHz]-frekvens
%omega[rad/s]-vinkelfrekvens
%l[km]-kabellengde
%dempning_dB[dB/km]-kabelens dempningskonstant i dB/km
%alfa[Np/km]-kabelens dempningskonstant i Np/km
%my[H/km]-permeabiliteten i vakuum
%epsiolonvak[F/km]-permittiviteten i vakuum
%epsilon_rel-relativ permittivitet = polyethylen
%lt-induktans per lengdeenhet
%ct-kapsitans per lengdeenhet
%rt-resistans per lengdeenhet
%beta[rad/km]-fasekonstant
%Z0-karakteristisk impedans
%gamma-propagsjonskonstant
%L-per-lengdeenhet-induktansmatrise
%C-per-lengdeenhet-kapasitansmatrise
%R-per-lengdeenhet-resistansmatrise
%Z0-matrise for generalisert karakteristisk impedans
%GAMMA-matrise for generalisert propagsjonskonstant
%*********************************************************************

dempning_dB=5.49;
l=2;

%faste parametre
%%%%%%%%%%%%%%%%
f=132*10^3;
omega = 2*pi*f;

my = 4*pi*10^(-7)*10^3; 
epsilon_vak = 8.8541878176*10^(-12)*10^3; 
epsilon_rel = 2.25; 
epsilon = epsilon_vak*epsilon_rel; %permittiviteten, F/m

alfa = dempning_dB*(1/(20*log10(exp(1))));

%matriser for to ledere
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
[L,C]=beregnInduktansKapasitans(0,0,2);
L2=L;
C2=C;

R=beregnResistans(dempning_dB,2);
R2=R;

%beregning av skalare parametre
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
ct=(3/2*(C(1,1)/2));
lt=(my*epsilon)/ct;
rt2=2*alfa*sqrt(lt/ct);
rt=R(1,1)*2;

beta = omega*sqrt(my*epsilon);
Z0=sqrt((rt+j*omega*lt)/(j*omega*ct));
gamma=sqrt((rt+j*omega*lt)*(j*omega*ct));

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Forskjellige dempningskonstanter
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
figure(1)
hold on

l=1;
x=[0.001:0.001:l];

alfa = 1*(1/(20*log10(exp(1)))); 
rt=2*alfa*sqrt(lt/ct);
Z0=sqrt((rt+j*omega*lt)/(j*omega*ct));
gamma=sqrt((rt+j*omega*lt)*(j*omega*ct));
Ztr = 20*log10(abs(Z0./(sinh(gamma*x))));
plot(x,(Ztr));
diffen=max(Ztr)-min(Ztr);


alfa = 2.75*(1/(20*log10(exp(1)))); 
rt=2*alfa*sqrt(lt/ct);
Z0=sqrt((rt+j*omega*lt)/(j*omega*ct));
gamma=sqrt((rt+j*omega*lt)*(j*omega*ct));
Ztr = 20*log10(abs(Z0./(sinh(gamma*x))));
plot(x,(Ztr),'red');
diffto=max(Ztr)-min(Ztr);


alfa = 5.49*(1/(20*log10(exp(1)))); 
rt=2*alfa*sqrt(lt/ct);
Z0=sqrt((rt+j*omega*lt)/(j*omega*ct));
gamma=sqrt((rt+j*omega*lt)*(j*omega*ct));
Ztr = 20*log10(abs(Z0./(sinh(gamma*x))));
plot(x,(Ztr),'green');
difftre=max(Ztr)-min(Ztr);

%tekst p akser for latex
xlabel('$x\left(km\right)$');
ylabel('$\left|Z_{tr}\right|\left(dB\right)$');

hold off

%*********************************************************************
%Beregning av transferfunksjon for enkel transmisjonslinje 
%*********************************************************************
figure(2)
hold on

%tekst p akser for matlab
%title('Overfringsfunksjon Ztr ')
% xlabel('x(km)');
% ylabel('|Ztr|(dB)');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%beregning med skalare parametre
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
l=1;
x=[0.001:0.001:l];
gamma=sqrt((rt+j*omega*lt)*j*omega*ct);
gammas=gamma;

Ztr = 20*log10(abs(Z0./(sinh(gamma*x))));
plot(x,(Ztr));

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Beregning med matriser
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%matrise for generalisert propagsjonskonstant
[GAMMA,Z0]=beregnGammaZ0(R,L,C);

b=1;
maxdiff=0;

for x=0.001:0.001:l

%beregning av A-matrise for toledere     
A=[funm((x*GAMMA), @cosh) (funm((x*GAMMA), @sinh))*Z0 ; (funm((x*(GAMMA.')), @sinh))*inv(Z0) funm((x*(GAMMA.')), @cosh)];


A11=A(1:2,1:2);
A12=A(1:2,3:4);
A21=A(3:4,1:2);
A22=A(3:4,3:4);

M=inv(A21);

Htr(b)=20*log10(abs(M(1)-M(3)-M(2)+M(4)));

b=b+1;

end

maxdiff=max(abs(Ztr-Htr));

x=[0.001:0.001:l];

plot(x,Htr,'red--');


% %legend for matlab
% legend('enkel transmisjonslinje med sekundrparamtre','enkel transmisjonslinje med primrparametre');

%tekst p akser for latex
xlabel('$x\left(km\right)$');
ylabel('$\left|Z_{tr}\right|\left(dB\right)$');


% %printer figurer i eps format til latex
% set(0,'DefaultTextInterpreter','none');
% laprint(2,'C:\Users\shild\Skole\Masteroppgave\Tex\enkelfig')
% laprint(1,'C:\Users\shild\Skole\Masteroppgave\Tex\dempningenkelfig')


