close all
clear all
clc
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%beregning av transferfunksjon for detektorslyfe med skalara parametre og
%matriser for sammenligning
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Parameterne som brukes i beregningen
%*********************************************************************
%f[kHz]-frekvens
%omega[rad/s]-vinkelfrekvens
%l[km]-kabellengde
%dempning_dB[dB/km]-kabelens dempningskonstant i dB/km
%alfa[Np/km]-kabelens dempningskonstant i Np/km
%my[H/km]-permeabiliteten i vakuum
%epsiolonvak[F/km]-permittiviteten i vakuum
%epsilon_rel-relativ permittivitet = polyethylen
%lt-induktans per lengdeenhet
%ct-kapsitans per lengdeenhet
%rt-resistans per lengdeenhet
%beta[rad/km]-fasekonstant
%Z0-karakteristisk impedans
%gamma-propagsjonskonstant
%L-per-lengdeenhet-induktansmatrise
%C-per-lengdeenhet-kapasitansmatrise
%R-per-lengdeenhet-resistansmatrise
%Z0-matrise for generalisert karakteristisk impedans
%GAMMA-matrise for generalisert propagsjonskonstant
%*********************************************************************

%faste parametre
%%%%%%%%%%
l=2; 
dempning_dB=5.49; 
f=132*10^3;
omega = 2*pi*f;
alfa = dempning_dB*(1/(20*log10(exp(1))));%Np/km

%permitivetet og permeabilitet
my = 4*pi*10^(-7)*10^3; %permeabiliteten i vakuum, H/km
epsilon_vak = 8.8541878176*10^(-12)*10^3; %permittiviteten i vakuum, F/km
epsilon_rel = 2.25; %permittiviteten til polyethylen
epsilon = epsilon_vak*epsilon_rel; %permittiviteten, F/m

%matriser for to ledere
[L,C]=beregnInduktansKapasitans(0,0,2);
R=beregnResistans(dempning_dB,2);

%beregning av skalare parametre
ct=3/2*(C(1,1)/2);
lt=(my*epsilon)/ct;
rt=2*alfa*sqrt(lt/ct);

%Beregning med sekundrparametre
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
f=132*10^3;
omega = 2*pi*f;
Z0=sqrt((rt+j*omega*lt)/(j*omega*ct));
beta = omega*sqrt(my*epsilon);
gamma=sqrt((rt+j*omega*lt)*(j*omega*ct));

x=0:0.001:l/2;

Ztr = 20*log10(abs((Z0/2)*((cosh(gamma*(l/2-x)))./(sinh(gamma*(l/2))))));

figure(1)
plot(x,Ztr);

%Beregning med primrparametre
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%generalisert propagasjonskonstant
[GAMMA,Z0]=beregnGammaZ0(R,L,C);


Htr=zeros(1,(l*100));
b=1;
maxdiff=0;

for x=0:0.001:l/2 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%A-matrise for lengden x (to ledere)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        
Ax=[funm((x*GAMMA), @cosh) (funm((x*GAMMA), @sinh))*Z0 ; (funm((x*(GAMMA.')), @sinh))*inv(Z0) funm((x*(GAMMA.')), @cosh)];

Ax11=Ax(1:2,1:2);
Ax12=Ax(1:2,3:4);
Ax21=Ax(3:4,1:2);
Ax22=Ax(3:4,3:4);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%A-matrise for lengden l-x (to ledere)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

Al=[funm(((l-x)*GAMMA), @cosh) (funm(((l-x)*GAMMA), @sinh))*Z0 ; (funm(((l-x)*(GAMMA.')), @sinh))*inv(Z0) funm(((l-x)*(GAMMA.')), @cosh)];

Al11=Al(1:2,1:2);
Al12=Al(1:2,3:4);
Al21=Al(3:4,1:2);
Al22=Al(3:4,3:4);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Beregning av transferfunksjon 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

M1=Ax21+Al21;
M2=Ax22-Al22;
M3=inv(Ax12+Al12);
M4=Al11-Ax11;

M=inv(M1+M2*M3*M4);

Htr(b)=20*log10(abs(M(1)-M(3)-M(2)+M(4)));

b=b+1;

end

hold on
x=0:0.001:l/2;
plot(x,Htr,'red--');

maxdiff=max(abs(Ztr-Htr));


%tekst p akser for latex
xlabel('$x\left(km\right)$');
ylabel('$\left|Z_{tr}\right|\left(dB\right)$');

%tekst p akser for matlab
% title('Overfringsfunksjon Htr ')
% xlabel('x(km)');
% ylabel('|Htr|(dB)');
% legend('Sekundrparametre','Primrparametre');

%printer figurer i eps format til latex
% set(0,'DefaultTextInterpreter','none');
% laprint(1,'C:\Users\shild\Skole\Masteroppgave\Tex\dobbelfig')
%laprint(1,'C:\Users\shild\Skole\Prosjekt\Tex\dempningenkelfig')

