clc
close all
clear all
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Beregning av transferfunksjon for en detektorslyfe med fire avhengige
%ledere. Sammenligning med detektorslyfe for to uavhengige toledere.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Parameterne som brukes i beregningen
%*********************************************************************
%f[kHz]-frekvens
%omega[rad/s]-vinkelfrekvens
%l[km]-lengden av detektorslyfe
%l2[km]-lengden av fellesstrekning
%dempning_dB[dB/km]-kabelens dempningskonstant i dB/km
%alfa[Np/km]-kabelens dempningskonstant i Np/km
%my[H/km]-permeabiliteten i vakuum
%epsiolonvak[F/km]-permittiviteten i vakuum
%epsilon_rel-relativ permittivitet = polyethylen
%lt-induktans per lengdeenhet
%ct-kapsitans per lengdeenhet
%rt-resistans per lengdeenhet
%beta[rad/km]-fasekonstant
%Z0-karakteristisk impedans
%gamma-propagsjonskonstant
%L-per-lengdeenhet-induktansmatrise
%C-per-lengdeenhet-kapasitansmatrise
%R-per-lengdeenhet-resistansmatrise
%Z0-matrise for generalisert karakteristisk impedans
%GAMMA-matrise for generalisert propagsjonskonstant
%*********************************************************************

%setter parametre
%%%%%%%%%%%%%%%%%
l2=1; 
l=2; 
dempning_dB=5.49;
f=132*10^3;
omega = 2*pi*f;
alfa = dempning_dB*(1/(20*log10(exp(1))));

my = 4*pi*10^(-7)*10^3;
epsilon_vak = 8.8541878176*10^(-12)*10^3; 
epsilon_rel = 2.25; 
epsilon = epsilon_vak*epsilon_rel; 

%%%%%%%%%%%%%%%%%%%%%%%
%Matriser for to ledere
%%%%%%%%%%%%%%%%%%%%%%%

[L,C]=beregnInduktansKapasitans(0,0,2);
R=beregnResistans(dempning_dB,2);
[GAMMA2,Z02]=beregnGammaZ0(R,L,C);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Matriser lengden l2 (to og to avhengige ledere)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

[L,C]=beregnInduktansKapasitans(0,0,2);
C=[C zeros(2,2);zeros(2,2) C];
L=my*epsilon*inv(C);
R=beregnResistans(dempning_dB,4);
[GAMMA,Z0]=beregnGammaZ0(R,L,C);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Matriser lengden l2 (fire avhenginge ledere
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

[L,C]=beregnInduktansKapasitans(0,0,4);
R=beregnResistans(dempning_dB,4);
[GAMMA4,Z04]=beregnGammaZ0(R,L,C);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%initaliserer parametre
b=1;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%beregner 8x8-matrise (fire avhengige ledere)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

A=[funm((l2*GAMMA4), @cosh) (funm((l2*GAMMA4), @sinh))*Z04; (funm((l2*(GAMMA4.')), @sinh))*inv(Z04) funm((l2*(GAMMA4.')), @cosh)];

A11=A(1:2,1:2);
A12=A(1:2,3:4);
A13=A(1:2,5:6);
A14=A(1:2,7:8);
A21=A(3:4,1:2);
A22=A(3:4,3:4);
A23=A(3:4,5:6);
A24=A(3:4,7:8);
A31=A(5:6,1:2);
A32=A(5:6,3:4);
A33=A(5:6,5:6);
A34=A(5:6,7:8);
A41=A(7:8,1:2);
A42=A(7:8,3:4);
A43=A(7:8,5:6);
A44=A(7:8,7:8); 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%beregner 8x8-matrise (to og to avhengige ledere)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

B=[funm((l2*GAMMA), @cosh) (funm((l2*GAMMA), @sinh))*Z0; (funm((l2*(GAMMA.')), @sinh))*inv(Z0) funm((l2*(GAMMA.')), @cosh)];

B11=B(1:2,1:2);
B12=B(1:2,3:4);
B13=B(1:2,5:6);
B14=B(1:2,7:8);
B21=B(3:4,1:2);
B22=B(3:4,3:4);
B23=B(3:4,5:6);
B24=B(3:4,7:8);
B31=B(5:6,1:2);
B32=B(5:6,3:4);
B33=B(5:6,5:6);
B34=B(5:6,7:8);
B41=B(7:8,1:2);
B42=B(7:8,3:4);
B43=B(7:8,5:6);
B44=B(7:8,7:8); 


for x=0:0.01:l/2 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%A-matrise for lengden x (to ledere)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

Ax=[funm((x*GAMMA2), @cosh) (funm((x*GAMMA2), @sinh))*Z02 ; (funm((x*(GAMMA2.')), @sinh))*inv(Z02) funm((x*(GAMMA2.')), @cosh)];
Ax4=Ax;

Ax11=Ax(1:2,1:2);
Ax12=Ax(1:2,3:4);
Ax21=Ax(3:4,1:2);
Ax22=Ax(3:4,3:4);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%A-matrise for lengden l-x (to ledere)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

Al=[funm(((l-x)*GAMMA2), @cosh) (funm(((l-x)*GAMMA2), @sinh))*Z02 ; (funm(((l-x)*(GAMMA2.')), @sinh))*inv(Z02) funm(((l-x)*(GAMMA2.')), @cosh)];

Al11=Al(1:2,1:2);
Al12=Al(1:2,3:4);
Al21=Al(3:4,1:2);
Al22=Al(3:4,3:4);

%Beregning av Ax-matrise med 8x8-matrisa
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
C11=A11*Ax11+A12*Al11+A13*Ax21+A14*Al21;
C12=A11*Ax12-A12*Al12+A13*Ax22-A14*Al22;
C21=A31*Ax11+A32*Al11+A33*Ax21+A34*Al21;
C22=A31*Ax12-A32*Al12+A33*Ax22-A34*Al22;

C=[C11 C12;C21 C22];
C1=C;

%Beregning av Al-matrise med 8x8-matrisa
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
D11=A21*Ax11+A22*Al11+A23*Ax21+A24*Al21;
D12=-A21*Ax12+A22*Al12-A23*Ax22+A24*Al22;
D21=A41*Ax11+A42*Al11+A43*Ax21+A44*Al21;
D22=-A41*Ax12+A42*Al12-A43*Ax22+A44*Al22;

D=[D11 D12;D21 D22];
D1=D;

%Beregner transferfunksjon fra C- og D-matrisa
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
M=inv((C21+D21)+(C22-D22)*inv(C12+D12)*(D11-C11));
Htr(b)=20*log10(abs(M(1)-M(3)-M(2)+M(4)));


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Beregning for to og to avhengige ledere
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Beregning av Ax-matrise med 8x8-matrisa
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
C11=B11*Ax11+B12*Al11+B13*Ax21+B14*Al21;
C12=B11*Ax12-B12*Al12+B13*Ax22-B14*Al22;
C21=B31*Ax11+B32*Al11+B33*Ax21+B34*Al21;
C22=B31*Ax12-B32*Al12+B33*Ax22-B34*Al22;

C=[C11 C12;C21 C22];
C2=C;

%Beregning av Al-matrise med 8x8-matrisa
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
D11=B21*Ax11+B22*Al11+B23*Ax21+B24*Al21;
D12=-B21*Ax12+B22*Al12-B23*Ax22+B24*Al22;
D21=B41*Ax11+B42*Al11+B43*Ax21+B44*Al21;
D22=-B41*Ax12+B42*Al12-B43*Ax22+B44*Al22;

D=[D11 D12;D21 D22];
D2=D;

%Beregner transferfunksjon fra C- og D-matrisa
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
M=inv((C21+D21)+(C22-D22)*inv(C12+D12)*(D11-C11));
Htr2(b)=20*log10(abs(M(1)-M(3)-M(2)+M(4)));


b=b+1;
end

figure(1)

hold on
x=0:0.01:l/2;
plot(x,Htr);
plot(x,Htr2,'red:');

title('Overfringsfunksjon Htr ')
%tekst p akser for matlab
xlabel('x(km)');
ylabel('|Htr|(dB)');
legend('Fire avhengige ledere','To og to avhengige ledere');







