close all
clear all
clc
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%beregning av transferfunksjon for detektorslyfe med skalare parametre og
%fullstendig modell for sammenligning
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Parameterne som brukes i beregningen
%*********************************************************************
%f[kHz]-frekvens
%omega[rad/s]-vinkelfrekvens
%l[km]-lengden av detektorslyfe som det ses p utgangsspenningen til 
%dempning_dB[dB/km]-kabelens dempningskonstant i dB/km
%alfa[Np/km]-kabelens dempningskonstant i Np/km
%my[H/km]-permeabiliteten i vakuum
%epsiolonvak[F/km]-permittiviteten i vakuum
%epsilon_rel-relativ permittivitet = polyethylen
%lt-induktans per lengdeenhet
%ct-kapsitans per lengdeenhet
%rt-resistans per lengdeenhet
%beta[rad/km]-fasekonstant
%Z0-karakteristisk impedans
%gamma-propagsjonskonstant
%L-per-lengdeenhet-induktansmatrise
%C-per-lengdeenhet-kapasitansmatrise
%R-per-lengdeenhet-resistansmatrise
%Z0-matrise for generalisert karakteristisk impedans
%GAMMA-matrise for generalisert propagsjonskonstant
%*********************************************************************

%parametre
%%%%%%%%%%
l=2; 
dempning_dB=5.49;

f=132*10^3;
omega = 2*pi*f;
alfa = dempning_dB*(1/(20*log10(exp(1))));%Np/km

%permitivetet og permeabilitet
my = 4*pi*10^(-7)*10^3; %permeabiliteten i vakuum, H/km
epsilon_vak = 8.8541878176*10^(-12)*10^3; %permittiviteten i vakuum, F/km
epsilon_rel = 2.25; %permittiviteten til polyethylen
epsilon = epsilon_vak*epsilon_rel; %permittiviteten, F/m


%Beregning med skalare parametre
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%henter verdier for beregning
[L,C]=beregnInduktansKapasitans(0,0,2);
R=beregnResistans(dempning_dB,2);
ct=3/2*(C(1,1)/2);
lt=(my*epsilon)/ct;
rt=2*alfa*sqrt(lt/ct);

%beregner sekundrparametre
f=132*10^3;
omega = 2*pi*f;
Z0=sqrt((rt+j*omega*lt)/(j*omega*ct));
beta = omega*sqrt(my*epsilon);
gamma=sqrt((rt+j*omega*lt)*(j*omega*ct));

x=0:0.001:l/2;

Ztr = 20*log10(abs((Z0/2)*((cosh(gamma*(l/2-x)))./(sinh(gamma*(l/2))))));

figure(1)
plot(x,Ztr);
hold on

%detektorslyfe beregnet med fullstendig modell
rettLengde=0;
sloyfeLengde=l;
[Htr1,z]=tosloyfer(0,0,1,1,rettLengde,sloyfeLengde,dempning_dB);
Htr=Htr1(1:length(x));

plot(x,Htr,'red:');

maxdiff=max(abs(Ztr-Htr))

%tekst p akser for matlab
title('Overfringsfunksjon Htr ')
xlabel('x(km)');
ylabel('|Htr|(dB)');
legend('Skalare parametre','Fullstendig modell');


