clc
clear all
%close all
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Beregning av transferfunksjon for en detektorslyfe med to og to avhengige
%ledere. Sammenligning av transferfunksjoner beregnet med 4x4-A-matrise og
%8x8-A-matrise
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%parametre
%%%%%%%%%%
l2=0.3; %lengden av strekningen hvor alle lederne ligger parallellt
l=2; %lengden av detektorslyfene

f=132*10^3;
omega = 2*pi*f;
dempning_dB=5.49;
alfa = dempning_dB*(1/(20*log10(exp(1))));%Np/km

my = 4*pi*10^(-7)*10^3; %permeabiliteten i vakuum, H/km
epsilon_vak = 8.8541878176*10^(-12)*10^3; %permittiviteten i vakuum, F/km
epsilon_rel = 2.25; %permittiviteten til polyethylen
epsilon = epsilon_vak*epsilon_rel; %permittiviteten, F/m

%Matriser for to ledere
%%%%%%%%%%%%%%%%%%%%%%%

%kapasitansmatrise
[L,C]=beregnInduktansKapasitans(0,0,2);

%resistansmatrise
R=beregnResistans(dempning_dB,2);

%generalisert propagasjonskonstant
[GAMMA2,Z02]=beregnGammaZ0(R,L,C);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Matriser lengden l2 (fire ledere) to og to avhengige
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%kapasitansmatrise
[L,C]=beregnInduktansKapasitans(0,0,4);

%induktansmatrise
L=my*epsilon*inv(C);
%resistansmatrise
R=beregnResistans(dempning_dB,4);

%generalisert propagasjonskonstant
[GAMMA4,Z04]=beregnGammaZ0(R,L,C);


%bergner 8x8-matrise
A=[funm((l2*GAMMA4), @cosh) (funm((l2*GAMMA4), @sinh))*Z04 ; (funm((l2*(GAMMA4.')), @sinh))*inv(Z04) funm((l2*(GAMMA4.')), @cosh)];

A11=A(1:2,1:2);
A12=A(1:2,3:4);
A13=A(1:2,5:6);
A14=A(1:2,7:8);
A21=A(3:4,1:2);
A22=A(3:4,3:4);
A23=A(3:4,5:6);
A24=A(3:4,7:8);
A31=A(5:6,1:2);
A32=A(5:6,3:4);
A33=A(5:6,5:6);
A34=A(5:6,7:8);
A41=A(7:8,1:2);
A42=A(7:8,3:4);
A43=A(7:8,5:6);
A44=A(7:8,7:8); 

Htr4=0;
b=1;
for x=0:0.001:l

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Beregning med 8x8-matrise
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%A-matrise for lengden x (to ledere)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

Ax=[funm((x*GAMMA2), @cosh) (funm((x*GAMMA2), @sinh))*Z02 ; (funm((x*(GAMMA2.')), @sinh))*inv(Z02) funm((x*(GAMMA2.')), @cosh)];
Ax4=Ax;
%Ax=[funm((x/2*GAMMA), @cosh) (funm((x/2*GAMMA), @sinh))*Z0 ; (funm((x/2*(GAMMA.')), @sinh))*inv(Z0) funm((x/2*(GAMMA.')), @cosh)];

Ax11=Ax(1:2,1:2);
Ax12=Ax(1:2,3:4);
Ax21=Ax(3:4,1:2);
Ax22=Ax(3:4,3:4);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%A-matrise for lengden l-x (to ledere)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

Al=[funm(((l-x)*GAMMA2), @cosh) (funm(((l-x)*GAMMA2), @sinh))*Z02 ; (funm(((l-x)*(GAMMA2.')), @sinh))*inv(Z02) funm(((l-x)*(GAMMA2.')), @cosh)];
% Al=[funm(((x/2)*GAMMA), @cosh) (funm(((x/2)*GAMMA), @sinh))*Z0 ; (funm(((x/2)*(GAMMA.')), @sinh))*inv(Z0) funm(((x/2)*(GAMMA.')), @cosh)];

Al11=Al(1:2,1:2);
Al12=Al(1:2,3:4);
Al21=Al(3:4,1:2);
Al22=Al(3:4,3:4);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Beregning av transferfunksjon
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
M1=Ax11*(A31+A41)+Al11*(A32+A42)+Ax21*(A33+A43)+Al21*(A34+A44);
M2=Ax12*(A31+A41)+Al12*(-A32-A42)+Ax22*(A33+A43)+Al22*(-A34-A44);
M3=inv(Ax12*(A21-A11)+Al12*(A12-A22)+Ax22*(A23-A13)+Al22*(A14-A24));
M4=Ax11*(A11-A21)+Al11*(A12-A22)+Ax21*(A13-A23)+Al21*(A14-A24);

M=inv(M1+M2*M3*M4);

Htr4(b)=20*log10(abs(M(1)-M(3)-M(2)+M(4)));

b=b+1;

end


figure(3)

hold on
x=0:0.001:l
plot(x,Htr4)
hold on

rettLengde=l2;
sloyfeLengde=l;
[Htr1,z]=tosloyfer(0,0,2,2,rettLengde,sloyfeLengde,dempning_dB);
plot(z,Htr1,'red:');

maxavvik=max(abs(Htr4-Htr1))

title('Overfringsfunksjon Htr ')
%tekst p akser for matlab
xlabel('x(km)');
ylabel('|Htr|(dB)');
legend('Fire ledere','Fullstendig modell');







