clc
%close all
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Beregning av transferfunksjon for en detektorslyfe med to uavhengige toledere
%Sammenligning av transferfunksjoner beregnet med 4x4-A-matrise og 8x8-A-matrise
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Parameterne som brukes i beregningen
%*********************************************************************
%f[kHz]-frekvens
%omega[rad/s]-vinkelfrekvens
%l[km]-lengden av detektorslyfe
%l2[km]-lengden av fellesstrekning
%dempning_dB[dB/km]-kabelens dempningskonstant i dB/km
%alfa[Np/km]-kabelens dempningskonstant i Np/km
%my[H/km]-permeabiliteten i vakuum
%epsiolonvak[F/km]-permittiviteten i vakuum
%epsilon_rel-relativ permittivitet = polyethylen
%lt-induktans per lengdeenhet
%ct-kapsitans per lengdeenhet
%rt-resistans per lengdeenhet
%beta[rad/km]-fasekonstant
%Z0-karakteristisk impedans
%gamma-propagsjonskonstant
%L-per-lengdeenhet-induktansmatrise
%C-per-lengdeenhet-kapasitansmatrise
%R-per-lengdeenhet-resistansmatrise
%Z0-matrise for generalisert karakteristisk impedans
%GAMMA-matrise for generalisert propagsjonskonstant
%*********************************************************************

%parametre
%%%%%%%%%%
l2=0.3; 
l=2; 
f=132*10^3;
omega = 2*pi*f;
alfa = 5.49*(1/(20*log10(exp(1))));%Np/km

%permittivitet og permeabilitet
my = 4*pi*10^(-7)*10^3; 
epsilon_vak = 8.8541878176*10^(-12)*10^3; 
epsilon_rel = 2.25; 
epsilon = epsilon_vak*epsilon_rel; 

%Matriser for to ledere
%%%%%%%%%%%%%%%%%%%%%%%

[L,C]=beregnInduktansKapasitans(0,0,2);
R=beregnResistans(dempning_dB,2);

%generalisert propagasjonskonstant
[GAMMA2,Z02]=beregnGammaZ0(R,L,C);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Matriser lengden l2 (fire ledere) to og to avhengige
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

[L,C]=beregnInduktansKapasitans(0,0,2);
C=[C zeros(2,2);zeros(2,2) C];
L=my*epsilon*inv(C);
R=beregnResistans(dempning_dB,4);

%generalisert propagasjonskonstant
[GAMMA4,Z04]=beregnGammaZ0(R,L,C);

avvik=0;
maxavvikx=0;
maxavvikl=0;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Beregning med to 4x4 A-matriser
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

Htr2=zeros(1,(l*100));
Htr4=zeros(1,(l*100));
U=zeros(1,(l*100));
b=1;

%%%%%%%%%%%%%%%%%%%%%
%beregner 8x8-matrise
%%%%%%%%%%%%%%%%%%%%%

A=[funm((l2*GAMMA4), @cosh) (funm((l2*GAMMA4), @sinh))*Z04 ; (funm((l2*(GAMMA4.')), @sinh))*inv(Z04) funm((l2*(GAMMA4.')), @cosh)];

A11=A(1:2,1:2);
A12=A(1:2,3:4);
A13=A(1:2,5:6);
A14=A(1:2,7:8);
A21=A(3:4,1:2);
A22=A(3:4,3:4);
A23=A(3:4,5:6);
A24=A(3:4,7:8);
A31=A(5:6,1:2);
A32=A(5:6,3:4);
A33=A(5:6,5:6);
A34=A(5:6,7:8);
A41=A(7:8,1:2);
A42=A(7:8,3:4);
A43=A(7:8,5:6);
A44=A(7:8,7:8); 

for x=0.001:0.01:l 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%A-matrise for lengden x (to ledere)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

Ax=[funm(((l2+x)*GAMMA2), @cosh) (funm(((l2+x)*GAMMA2), @sinh))*Z02 ; (funm(((l2+x)*(GAMMA2.')), @sinh))*inv(Z02) funm(((l2+x)*(GAMMA2.')), @cosh)];
Ax2=Ax;


Ax11=Ax(1:2,1:2);
Ax12=Ax(1:2,3:4);
Ax21=Ax(3:4,1:2);
Ax22=Ax(3:4,3:4);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%A-matrise for lengden l-x (to ledere)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

Al=[funm(((l2+l-x)*GAMMA2), @cosh) (funm(((l2+l-x)*GAMMA2), @sinh))*Z02 ; (funm(((l2+l-x)*(GAMMA2.')), @sinh))*inv(Z02) funm(((l2+l-x)*(GAMMA2.')), @cosh)];
Al2=Al;

Al11=Al(1:2,1:2);
Al12=Al(1:2,3:4);
Al21=Al(3:4,1:2);
Al22=Al(3:4,3:4);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Beregning av transferfunksjon 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

M1=Ax21+Al21;
M2=Ax22-Al22;
M3=inv(Ax12+Al12);
M4=Al11-Ax11;

M=inv(M1+M2*M3*M4);

Htr2(b)=20*log10(abs(M(1)-M(3)-M(2)+M(4)));

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Beregning med 8x8-matrise
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%A-matrise for lengden x (to ledere)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

Ax=[funm((x*GAMMA2), @cosh) (funm((x*GAMMA2), @sinh))*Z02 ; (funm((x*(GAMMA2.')), @sinh))*inv(Z02) funm((x*(GAMMA2.')), @cosh)];
Ax4=Ax;

Ax11=Ax(1:2,1:2);
Ax12=Ax(1:2,3:4);
Ax21=Ax(3:4,1:2);
Ax22=Ax(3:4,3:4);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%A-matrise for lengden l-x (to ledere)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

Al=[funm(((l-x)*GAMMA2), @cosh) (funm(((l-x)*GAMMA2), @sinh))*Z02 ; (funm(((l-x)*(GAMMA2.')), @sinh))*inv(Z02) funm(((l-x)*(GAMMA2.')), @cosh)];

Al11=Al(1:2,1:2);
Al12=Al(1:2,3:4);
Al21=Al(3:4,1:2);
Al22=Al(3:4,3:4);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Beregning av transferfunksjon
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
M1=Ax11*(A31+A41)+Al11*(A32+A42)+Ax21*(A33+A43)+Al21*(A34+A44);
M2=Ax12*(A31+A41)+Al12*(-A32-A42)+Ax22*(A33+A43)+Al22*(-A34-A44);
M3=inv(Ax12*(A21-A11)+Al12*(A12-A22)+Ax22*(A23-A13)+Al22*(A14-A24));
M4=Ax11*(A11-A21)+Al11*(A12-A22)+Ax21*(A13-A23)+Al21*(A14-A24);

M=inv(M1+M2*M3*M4);

Htr4(b)=20*log10(abs(M(1)-M(3)-M(2)+M(4)));

%Beregning av Ax-matrise med 8x8-matrisa
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
C11=A11*Ax11+A12*Al11+A13*Ax21+A14*Al21;
C12=A11*Ax12-A12*Al12+A13*Ax22-A14*Al22;
C21=A31*Ax11+A32*Al11+A33*Ax21+A34*Al21;
C22=A31*Ax12-A32*Al12+A33*Ax22-A34*Al22;

C=[C11 C12;C21 C22];

%beregner max avvik for matriseelementer i matrisene Ax2 og C
for i=1:1:16
    avvik=abs(Ax2(i)-C(i));
    if (avvik>maxavvikx)
    maxavvikx=avvik;   
    end
end

%Beregning av Al-matrise med 8x8-matrisa
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
D11=A21*Ax11+A22*Al11+A23*Ax21+A24*Al21;
D12=-A21*Ax12+A22*Al12-A23*Ax22+A24*Al22;
D21=A41*Ax11+A42*Al11+A43*Ax21+A44*Al21;
D22=-A41*Ax12+A42*Al12-A43*Ax22+A44*Al22;

D=[D11 D12;D21 D22];

%beregner max avvik for matriseelementer i matrisene Ax2 og C
for i=1:1:16
    avvik=abs(Al2(i)-D(i));
    if (avvik>maxavvikl)
    maxavvikl=avvik;   
    end
end

%beregner transferfunksjon fra C- og D-matrisa
M=inv((C21+D21)+(C22-D22)*inv(C12+D12)*(D11-C11));
HtrCD(b)=20*log10(abs(M(1)-M(3)-M(2)+M(4)));

b=b+1;
end
maxavvikx;
maxavvikl;

maxavvikHtr=max(abs(HtrCD-Htr2));

figure(3)

hold on
x=0.001:0.01:l;
plot(x,Htr2);
plot(x,Htr4,'red-')
plot(x,HtrCD,'green:');

%tekst p akser for matlab
title('Overfringsfunksjon Htr ')
xlabel('x(km)');
ylabel('|Htr|(dB)');
legend('To ledere','Fire ledere','8x8 til 4x4');







