clc
close all
clear all
%************************************************************************
%Beregning av transferfunksjon for forksjellige lengder av detektorslyfa
%************************************************************************

%Parameterne som brukes i beregningen
%*********************************************************************
%f[kHz]-frekvens
%omega[rad/s]-vinkelfrekvens
%L[km]-lengden av detektorslyfe
%dempning_dB[dB/km]-kabelens dempningskonstant i dB/km
%alfa[Np/km]-kabelens dempningskonstant i Np/km
%my[H/km]-permeabiliteten i vakuum
%epsiolonvak[F/km]-permittiviteten i vakuum
%epsilon_rel-relativ permittivitet = polyethylen
%lt-induktans per lengdeenhet
%ct-kapsitans per lengdeenhet
%rt-resistans per lengdeenhet
%beta[rad/km]-fasekonstant
%Z0-karakteristisk impedans
%gamma-propagsjonskonstant
%L-per-lengdeenhet-induktansmatrise
%C-per-lengdeenhet-kapasitansmatrise
%R-per-lengdeenhet-resistansmatrise
%*********************************************************************

%setter parametre
dempning_dB=5.49;
f=132*10^3;
omega = 2*pi*f;
my = 4*pi*10^(-7)*10^3; 
epsilon_vak = 8.8541878176*10^(-12)*10^3; 
epsilon_rel = 2.25; 
epsilon = epsilon_vak*epsilon_rel; 

%beregner parametre fra matriser
[L,C]=beregnInduktansKapasitans(0,0,2);
R=beregnResistans(dempning_dB,2);
ct=(3/2*(C(1,1)/2));
lt=(my*epsilon)/ct;
rt=R(1,1)*2;
beta = omega*sqrt(my*epsilon);
Z0=sqrt((rt+j*omega*lt)/(j*omega*ct));
gamma=sqrt((rt+j*omega*lt)*(j*omega*ct));

%*********************************************************************
%beregner og plotter overfringsfunksjonen for forskjellige lengder, L
%*********************************************************************

figure(5)
%title('Overfringsfunksjon Ztr, for dempningskonstant alfa=5.49dB/km')

%tekst p akser for matlab
xlabel('x(km)');
ylabel('|Ztr|(dB)');
%tekst p akser for latex
xlabel('$x\left(km\right)$');
ylabel('$\left|Z_{tr}\right|\left(dB\right)$');

hold on

%plotter alle funksjonene for x fra 0 til 1km
x=[0:0.001:1];

%lengde L=0.5km
L=0.5;
Ztr = 20*log10(abs((Z0/2)*((cosh(gamma*(L/2-x)))./(sinh(gamma*(L/2))))));
plot(x,(Ztr));
diffen=max(Ztr)-min(Ztr);

%lengde L=1.0km
L=1.0;
Ztr = 20*log10(abs((Z0/2)*((cosh(gamma*(L/2-x)))./(sinh(gamma*(L/2))))));
plot(x,(Ztr),'red');
diffto=max(Ztr)-min(Ztr);

%lengde L=1.5km
L=1.5;
Ztr = 20*log10(abs((Z0/2)*((cosh(gamma*(L/2-x)))./(sinh(gamma*(L/2))))));
plot(x,(Ztr),'green');
difftre=max(Ztr)-min(Ztr);

%lengde L=2.0km
L=2.0;
Ztr = 20*log10(abs((Z0/2)*((cosh(gamma*(L/2-x)))./(sinh(gamma*(L/2))))));
plot(x,(Ztr),'black');
difffire=max(Ztr)-min(Ztr);

%%legend for matlab
% legend('L=0,5km','L=1km','L=1,5km','L=2km');
%%legend for latex
% %legend('$L=0,5$km','$L=1$km','$L=1,5$km','$L=2$km');
% legend('Location','Best');
% legend('boxoff');

hold off

%*********************************************************************
%beregner dempning i forhold til bra (L=1.5) og drlig kabellengde (L=2)
%*********************************************************************

figure(6)
%title('Forskjellige dempningskonstanter alfa for bra og drlig tilfelle av kabellengde')

%tekst p akser matlab
xlabel('x(km)');
ylabel('|Ztr|(dB)');
%tekst p akser latex
xlabel('$x\left(km\right)$');
ylabel('$\left|Z_{tr}\right|\left(dB\right)$');

hold on
%plotter alle funskjoner for x fra 0 til 1 km
x=[0:0.001:1];

L=1.5;

alfa = 1*(1/(20*log10(exp(1)))); %Np/km
gamma = alfa + j*beta;
Ztr = 20*log10(abs((Z0/2)*((cosh(gamma*(L/2-x)))./(sinh(gamma*(L/2))))));
plot(x,(Ztr),':');
diffen=max(Ztr)-min(Ztr);


alfa = 2.75*(1/(20*log10(exp(1)))); %Np/km
gamma = alfa + j*beta;
Ztr = 20*log10(abs((Z0/2)*((cosh(gamma*(L/2-x)))./(sinh(gamma*(L/2))))));
plot(x,(Ztr),'--');
diffto=max(Ztr)-min(Ztr);


alfa = 5.49*(1/(20*log10(exp(1)))); %Np/km
gamma = alfa + j*beta;
Ztr = 20*log10(abs((Z0/2)*((cosh(gamma*(L/2-x)))./(sinh(gamma*(L/2))))));
plot(x,(Ztr));
difftre=max(Ztr)-min(Ztr);


%Forskjellig dempning for kabellengde 2km
%*********************************************************************
L=2;

alfa = 1*(1/(20*log10(exp(1)))); %Np/km
gamma = alfa + j*beta;
Ztr = 20*log10(abs((Z0/2)*((cosh(gamma*(L/2-x)))./(sinh(gamma*(L/2))))));
plot(x,(Ztr),'red:');
diffen=max(Ztr)-min(Ztr);

alfa = 2.75*(1/(20*log10(exp(1)))); %Np/km
gamma = alfa + j*beta;
Ztr = 20*log10(abs((Z0/2)*((cosh(gamma*(L/2-x)))./(sinh(gamma*(L/2))))));
plot(x,(Ztr),'red--');
diffto=max(Ztr)-min(Ztr);

alfa = 5.49*(1/(20*log10(exp(1)))); %Np/km
gamma = alfa + j*beta;
Ztr = 20*log10(abs((Z0/2)*((cosh(gamma*(L/2-x)))./(sinh(gamma*(L/2))))));
plot(x,(Ztr),'red');
difftre=max(Ztr)-min(Ztr);

%%legend for matlab
% legend('L=1km,\alpha=1dB/km','L=1km,\alpha=2.75dB/km','L=1km,\alpha=5,49dB/km','L=2km,\alpha=1dB/km','L=2km,\alpha=2.75dB/km','L=2km,\alpha=5,49dB/km');
% legend('Location','Northwest');
% legend('Location','Best');
% legend('boxoff');

% %printer figurer i eps format til latex
% set(0,'DefaultTextInterpreter','none');
% laprint(5,'C:\Users\shild\Skole\Masteroppgave\Tex\dobbellengderfig');
% laprint(6,'C:\Users\shild\Skole\Masteroppgave\Tex\dempningfig');

