%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%funksjon som beregner transferfunksjonen for et system bestende av to
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Inngangsparametre:
%%%%%%%%%%%%%%%%%%%
%phi1-vridning kabel 1
%phi2-vridning kabel 2
%stromPos-kabel som ptrykkes signal (1 eller 2)
%sloyfePos-kabel som det ses p utgangsspeningen til (1 eller 2)
%rettLengde-lengden av felles strekning for kabel 1 og 2
%sloyfeLengde-lengden av detektorslyfa
%dempning_dB-kabelens dempningskonstant i dB
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function[Htr,x]=tosloyfer(phi1,phi2,stromPos,sloyfePos,rettLengde,sloyfeLengde,dempning_dB);

%Parameterne som brukes i beregningen
%*********************************************************************
%f[kHz]-frekvens
%omega[rad/s]-vinkelfrekvens
%phi1-vridning kabel 1
%phi2-vridning kabel 2
%l[km]-lengden av detektorslyfe som det ses p utgangsspenningen til 
%l2[km]-lengden av fellesstrekning
%l3[km]-lengden av den andre detektorslyfa 
%dempning_dB[dB/km]-kabelens dempningskonstant i dB/km
%alfa[Np/km]-kabelens dempningskonstant i Np/km
%my[H/km]-permeabiliteten i vakuum
%epsiolonvak[F/km]-permittiviteten i vakuum
%epsilon_rel-relativ permittivitet = polyethylen
%lt-induktans per lengdeenhet
%ct-kapsitans per lengdeenhet
%rt-resistans per lengdeenhet
%beta[rad/km]-fasekonstant
%Z0-karakteristisk impedans
%gamma-propagsjonskonstant
%L-per-lengdeenhet-induktansmatrise
%C-per-lengdeenhet-kapasitansmatrise
%R-per-lengdeenhet-resistansmatrise
%Z0-matrise for generalisert karakteristisk impedans
%GAMMA-matrise for generalisert propagsjonskonstant
%*********************************************************************


%Lengder
l=sloyfeLengde;
l2=rettLengde;
l3=sloyfeLengde;

%permittivitet og permeabilitet
my = 4*pi*10^(-7)*10^3; 
epsilon_vak = 8.8541878176*10^(-12)*10^3; 
epsilon_rel = 2.25; 
epsilon = epsilon_vak*epsilon_rel; 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Matriser for to ledere
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
[L,C]=beregnInduktansKapasitans(phi1,phi2,2);
R=beregnResistans(dempning_dB,2);
[GAMMA2,Z02]=beregnGammaZ0(R,L,C);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Matriser for tte ledere
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
[L,C]=beregnInduktansKapasitans(phi1,phi2,8);
R=beregnResistans(dempning_dB,8);
[GAMMA8,Z08]=beregnGammaZ0(R,L,C);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%matrise for tte ledere hvis det ikke er avhengighet mellom ledere i
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if(stromPos==sloyfePos)
[L,C]=beregnInduktansKapasitans(phi1,phi2,4)
C=[C zeros(4,4);zeros(4,4) C];
L=my*epsilon*inv(C);

R=beregnResistans(dempning_dB,8);

[GAMMA8,Z08]=beregnGammaZ0(R,L,C);

end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Initialisering
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Imin=[1 0 0 0;0 1 0 0;0 0 -1 0;0 0 0 -1];
b=1;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Beregning av 16x16 A-matrise for lengden l2
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
A=[funm((l2*GAMMA8), @cosh) (funm((l2*GAMMA8), @sinh))*Z08 ; (funm((l2*(GAMMA8.')), @sinh))*inv(Z08) funm((l2*(GAMMA8.')), @cosh)];
A;

Al2=A;

A11=A(1:2,1:2);
A12=A(1:2,3:4);
A13=A(1:2,5:6);
A14=A(1:2,7:8);
A15=A(1:2,9:10);
A16=A(1:2,11:12);
A17=A(1:2,13:14);
A18=A(1:2,15:16);

A21=A(3:4,1:2);
A22=A(3:4,3:4);
A23=A(3:4,5:6);
A24=A(3:4,7:8);
A25=A(3:4,9:10);
A26=A(3:4,11:12);
A27=A(3:4,13:14);
A28=A(3:4,15:16);

A31=A(5:6,1:2);
A32=A(5:6,3:4);
A33=A(5:6,5:6);
A34=A(5:6,7:8);
A35=A(5:6,9:10);
A36=A(5:6,11:12);
A37=A(5:6,13:14);
A38=A(5:6,15:16);

A41=A(7:8,1:2);
A42=A(7:8,3:4);
A43=A(7:8,5:6);
A44=A(7:8,7:8);
A45=A(7:8,9:10);
A46=A(7:8,11:12);
A47=A(7:8,13:14);
A48=A(7:8,15:16);

A51=A(9:10,1:2);
A52=A(9:10,3:4);
A53=A(9:10,5:6);
A54=A(9:10,7:8);
A55=A(9:10,9:10);
A56=A(9:10,11:12);
A57=A(9:10,13:14);
A58=A(9:10,15:16);

A61=A(11:12,1:2);
A62=A(11:12,3:4);
A63=A(11:12,5:6);
A64=A(11:12,7:8);
A65=A(11:12,9:10);
A66=A(11:12,11:12);
A67=A(11:12,13:14);
A68=A(11:12,15:16);

A71=A(13:14,1:2);
A72=A(13:14,3:4);
A73=A(13:14,5:6);
A74=A(13:14,7:8);
A75=A(13:14,9:10);
A76=A(13:14,11:12);
A77=A(13:14,13:14);
A78=A(13:14,15:16);

A81=A(15:16,1:2);
A82=A(15:16,3:4);
A83=A(15:16,5:6);
A84=A(15:16,7:8);
A85=A(15:16,9:10);
A86=A(15:16,11:12);
A87=A(15:16,13:14);
A88=A(15:16,15:16);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Beregning av A-merket-matrise
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

Am11=[A11 A15;A51 A55];
Am12=[A12 A16;A52 A56];
Am13=[A13 A17;A53 A57];
Am14=[A14 A18;A54 A58];

Am21=[A21 A25;A61 A65];
Am22=[A22 A26;A62 A66];
Am23=[A23 A27;A63 A67];
Am24=[A24 A28;A64 A68];

Am31=[A31 A35;A71 A75];
Am32=[A32 A36;A72 A76];
Am33=[A33 A37;A73 A77];
Am34=[A34 A38;A74 A78];

Am41=[A41 A45;A81 A85];
Am42=[A42 A46;A82 A86];
Am43=[A43 A47;A83 A87];
Am44=[A44 A48;A84 A88];

Am=[Am11 Am12 Am13 Am14;Am21 Am22 Am23 Am24;Am31 Am32 Am33 Am34;Am41 Am42 Am43 Am44];
Am;


if(sloyfePos==1)
Am=[Am(9:12,1:16);Am(13:16,1:16);Am(1:4,1:16);Am(5:8,1:16)];
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Beregning av 4x4 B-matrise for lengden l3
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
B=[funm((l3*GAMMA2), @cosh) (funm((l3*GAMMA2), @sinh))*Z02 ; (funm((l3*(GAMMA2.')), @sinh))*inv(Z02) funm((l3*(GAMMA2.')), @cosh)];
B1=B;

Bm=B*Imin;


for x=0:0.001:l
%for x=0


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Beregning av 4x4 C-matrise for lengden x (to ledere)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

C=[funm(((x)*GAMMA2), @cosh) (funm(((x)*GAMMA2), @sinh))*Z02 ; (funm(((x)*(GAMMA2.')), @sinh))*inv(Z02) funm(((x)*(GAMMA2.')), @cosh)];
C1=C;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Beregning av 4x4 D-matrise for lengden l-x (to ledere)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

D=[funm(((l-x)*GAMMA2), @cosh) (funm(((l-x)*GAMMA2), @sinh))*Z02 ; (funm(((l-x)*(GAMMA2.')), @sinh))*inv(Z02) funm(((l-x)*(GAMMA2.')), @cosh)];
D1=D;

Dm=D*Imin;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Beregning av elementer i E-matrise (slyfe nederst)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

E11=Am(1:4,1:4)*Bm+Am(1:4,5:8);
E12=Am(1:4,9:12)*C+Am(1:4,13:16)*Dm;
E21=Am(5:8,1:4)*Bm+Am(5:8,5:8);
E22=Am(5:8,9:12)*C+Am(5:8,13:16)*Dm;
E31=Am(9:12,1:4)*Bm+Am(9:12,5:8);
E32=Am(9:12,9:12)*C+Am(9:12,13:16)*Dm;
E41=Am(13:16,1:4)*Bm+Am(13:16,5:8);
E42=Am(13:16,9:12)*C+Am(13:16,13:16)*Dm;

E2=[E11 E12;E21 E22;E31 E32;E41 E42];    

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Beregning av 4x4 F-matrise
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if(stromPos==1)
F=(-Imin*E11+E21)*inv(Imin*E31-E41)*(E42-Imin*E32)+(-Imin*E12+E22);    
else
if(stromPos==2)
F=(-Imin*E31+E41)*inv(Imin*E11-E21)*(E22-Imin*E12)+(-Imin*E32+E42);    
end
end

FI=inv(F);

FI13=FI(1,3);
FI14=FI(1,4);
FI23=FI(2,3);
FI24=FI(2,4);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Beregning av transferfunksjon
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

Htr(b)=20*log10(abs(FI13-FI14-FI23+FI24));

b=b+1;

end

x=0:0.001:l;


% title('Overfringsfunksjon, Htr')
% %tekst p akser for matlab
% xlabel('x(km)');
% ylabel('|Htr|(dB)');
% %legend('tte ledere','Slyfe nederst');


